@@ -67,7 +67,9 @@ class Collection:
                     limit=limit,
                     order_by=order_by)
         if len(unique_operators) > 1:
-            raise ValueError('Cannot have different operators in same query')
+            allowed_mixed_operators = {u'>=', u'<=', u'==', u'>', u'<', u'in'}
+            if len(set(unique_operators) - allowed_mixed_operators) != 0:
+                raise ValueError(f"Only following operators can be mixed: {allowed_mixed_operators}")
 
         # Init docs object
         docs = self.collection
@@ -147,7 +149,7 @@ class Collection:
     def query_by_attributes(self,
                             attributes: List[str],
                             values: List[Any],
-                            operator: Optional[str] = u'==',
+                            operators: List[str],
                             limit: Optional[int] = None,
                             order_by: Optional[List[Tuple[str, OrderByDirection]]] = []
                             ) -> List[Any]:
@@ -157,7 +159,7 @@ class Collection:
         return self._query(
             conditions=[
                 (attribute, operator, value)
-                for attribute, value in zip(attributes, values)
+                for attribute, operator, value in zip(attributes, operators, values)
             ],
             limit=limit,
             order_by=order_by)
